import type { PaginationConfiguration } from "@smithy/types";
import { CognitoIdentityClient } from "../CognitoIdentityClient";
/**
 * @public
 */
export interface CognitoIdentityPaginationConfiguration extends PaginationConfiguration {
    client: CognitoIdentityClient;
}
