export declare const AmbiguousRoleResolutionType: {
  readonly AUTHENTICATED_ROLE: "AuthenticatedRole";
  readonly DENY: "Deny";
};
export type AmbiguousRoleResolutionType =
  (typeof AmbiguousRoleResolutionType)[keyof typeof AmbiguousRoleResolutionType];
export declare const ErrorCode: {
  readonly ACCESS_DENIED: "AccessDenied";
  readonly INTERNAL_SERVER_ERROR: "InternalServerError";
};
export type ErrorCode = (typeof ErrorCode)[keyof typeof ErrorCode];
export declare const MappingRuleMatchType: {
  readonly CONTAINS: "Contains";
  readonly EQUALS: "Equals";
  readonly NOT_EQUAL: "NotEqual";
  readonly STARTS_WITH: "StartsWith";
};
export type MappingRuleMatchType =
  (typeof MappingRuleMatchType)[keyof typeof MappingRuleMatchType];
export declare const RoleMappingType: {
  readonly RULES: "Rules";
  readonly TOKEN: "Token";
};
export type RoleMappingType =
  (typeof RoleMappingType)[keyof typeof RoleMappingType];
