import { TypeRegistry } from "@smithy/core/schema";
import {
  StaticErrorSchema,
  StaticOperationSchema,
  StaticStructureSchema,
} from "@smithy/types";
export declare var CognitoIdentityServiceException$: StaticErrorSchema;
export declare var ConcurrentModificationException$: StaticErrorSchema;
export declare var DeveloperUserAlreadyRegisteredException$: StaticErrorSchema;
export declare var ExternalServiceException$: StaticErrorSchema;
export declare var InternalErrorException$: StaticErrorSchema;
export declare var InvalidIdentityPoolConfigurationException$: StaticErrorSchema;
export declare var InvalidParameterException$: StaticErrorSchema;
export declare var LimitExceededException$: StaticErrorSchema;
export declare var NotAuthorizedException$: StaticErrorSchema;
export declare var ResourceConflictException$: StaticErrorSchema;
export declare var ResourceNotFoundException$: StaticErrorSchema;
export declare var TooManyRequestsException$: StaticErrorSchema;
export declare const errorTypeRegistries: TypeRegistry[];
export declare var CognitoIdentityProvider$: StaticStructureSchema;
export declare var CreateIdentityPoolInput$: StaticStructureSchema;
export declare var Credentials$: StaticStructureSchema;
export declare var DeleteIdentitiesInput$: StaticStructureSchema;
export declare var DeleteIdentitiesResponse$: StaticStructureSchema;
export declare var DeleteIdentityPoolInput$: StaticStructureSchema;
export declare var DescribeIdentityInput$: StaticStructureSchema;
export declare var DescribeIdentityPoolInput$: StaticStructureSchema;
export declare var GetCredentialsForIdentityInput$: StaticStructureSchema;
export declare var GetCredentialsForIdentityResponse$: StaticStructureSchema;
export declare var GetIdentityPoolRolesInput$: StaticStructureSchema;
export declare var GetIdentityPoolRolesResponse$: StaticStructureSchema;
export declare var GetIdInput$: StaticStructureSchema;
export declare var GetIdResponse$: StaticStructureSchema;
export declare var GetOpenIdTokenForDeveloperIdentityInput$: StaticStructureSchema;
export declare var GetOpenIdTokenForDeveloperIdentityResponse$: StaticStructureSchema;
export declare var GetOpenIdTokenInput$: StaticStructureSchema;
export declare var GetOpenIdTokenResponse$: StaticStructureSchema;
export declare var GetPrincipalTagAttributeMapInput$: StaticStructureSchema;
export declare var GetPrincipalTagAttributeMapResponse$: StaticStructureSchema;
export declare var IdentityDescription$: StaticStructureSchema;
export declare var IdentityPool$: StaticStructureSchema;
export declare var IdentityPoolShortDescription$: StaticStructureSchema;
export declare var ListIdentitiesInput$: StaticStructureSchema;
export declare var ListIdentitiesResponse$: StaticStructureSchema;
export declare var ListIdentityPoolsInput$: StaticStructureSchema;
export declare var ListIdentityPoolsResponse$: StaticStructureSchema;
export declare var ListTagsForResourceInput$: StaticStructureSchema;
export declare var ListTagsForResourceResponse$: StaticStructureSchema;
export declare var LookupDeveloperIdentityInput$: StaticStructureSchema;
export declare var LookupDeveloperIdentityResponse$: StaticStructureSchema;
export declare var MappingRule$: StaticStructureSchema;
export declare var MergeDeveloperIdentitiesInput$: StaticStructureSchema;
export declare var MergeDeveloperIdentitiesResponse$: StaticStructureSchema;
export declare var RoleMapping$: StaticStructureSchema;
export declare var RulesConfigurationType$: StaticStructureSchema;
export declare var SetIdentityPoolRolesInput$: StaticStructureSchema;
export declare var SetPrincipalTagAttributeMapInput$: StaticStructureSchema;
export declare var SetPrincipalTagAttributeMapResponse$: StaticStructureSchema;
export declare var TagResourceInput$: StaticStructureSchema;
export declare var TagResourceResponse$: StaticStructureSchema;
export declare var UnlinkDeveloperIdentityInput$: StaticStructureSchema;
export declare var UnlinkIdentityInput$: StaticStructureSchema;
export declare var UnprocessedIdentityId$: StaticStructureSchema;
export declare var UntagResourceInput$: StaticStructureSchema;
export declare var UntagResourceResponse$: StaticStructureSchema;
export declare var CreateIdentityPool$: StaticOperationSchema;
export declare var DeleteIdentities$: StaticOperationSchema;
export declare var DeleteIdentityPool$: StaticOperationSchema;
export declare var DescribeIdentity$: StaticOperationSchema;
export declare var DescribeIdentityPool$: StaticOperationSchema;
export declare var GetCredentialsForIdentity$: StaticOperationSchema;
export declare var GetId$: StaticOperationSchema;
export declare var GetIdentityPoolRoles$: StaticOperationSchema;
export declare var GetOpenIdToken$: StaticOperationSchema;
export declare var GetOpenIdTokenForDeveloperIdentity$: StaticOperationSchema;
export declare var GetPrincipalTagAttributeMap$: StaticOperationSchema;
export declare var ListIdentities$: StaticOperationSchema;
export declare var ListIdentityPools$: StaticOperationSchema;
export declare var ListTagsForResource$: StaticOperationSchema;
export declare var LookupDeveloperIdentity$: StaticOperationSchema;
export declare var MergeDeveloperIdentities$: StaticOperationSchema;
export declare var SetIdentityPoolRoles$: StaticOperationSchema;
export declare var SetPrincipalTagAttributeMap$: StaticOperationSchema;
export declare var TagResource$: StaticOperationSchema;
export declare var UnlinkDeveloperIdentity$: StaticOperationSchema;
export declare var UnlinkIdentity$: StaticOperationSchema;
export declare var UntagResource$: StaticOperationSchema;
export declare var UpdateIdentityPool$: StaticOperationSchema;
