/**
 * @public
 * @enum
 */
export declare const AmbiguousRoleResolutionType: {
    readonly AUTHENTICATED_ROLE: "AuthenticatedRole";
    readonly DENY: "Deny";
};
/**
 * @public
 */
export type AmbiguousRoleResolutionType = (typeof AmbiguousRoleResolutionType)[keyof typeof AmbiguousRoleResolutionType];
/**
 * @public
 * @enum
 */
export declare const ErrorCode: {
    readonly ACCESS_DENIED: "AccessDenied";
    readonly INTERNAL_SERVER_ERROR: "InternalServerError";
};
/**
 * @public
 */
export type ErrorCode = (typeof ErrorCode)[keyof typeof ErrorCode];
/**
 * @public
 * @enum
 */
export declare const MappingRuleMatchType: {
    readonly CONTAINS: "Contains";
    readonly EQUALS: "Equals";
    readonly NOT_EQUAL: "NotEqual";
    readonly STARTS_WITH: "StartsWith";
};
/**
 * @public
 */
export type MappingRuleMatchType = (typeof MappingRuleMatchType)[keyof typeof MappingRuleMatchType];
/**
 * @public
 * @enum
 */
export declare const RoleMappingType: {
    readonly RULES: "Rules";
    readonly TOKEN: "Token";
};
/**
 * @public
 */
export type RoleMappingType = (typeof RoleMappingType)[keyof typeof RoleMappingType];
